@@ -1,5 +1,5 @@
 package POEx::WorkerPool::Role::WorkerPool::Worker;
-our $VERSION = '0.092530';
+our $VERSION = '0.092560';
 
 
 #ABSTRACT: A role that provides common semantics for Workers
@@ -34,7 +34,7 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
     use aliased 'POEx::Role::Event';
 
 
-    has job_class => ( is => 'ro', isa => ClassName, required => 1);
+    has job_classes => ( is => 'ro', isa => ArrayRef[ClassName], required => 1);
 
 
     has uuid => ( is => 'ro', isa => Str, lazy => 1, default => sub { Data::UUID->new()->create_str() } );
@@ -82,7 +82,7 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
     has child_wheel => ( is => 'ro', isa => Wheel, lazy_build => 1 );
     method _build_child_wheel
     {
-        my $class = $self->job_class;
+        my $classes = $self->job_classes;
         my $wheel = POE::Wheel::Run->new
         (
             Program => sub 
@@ -92,7 +92,7 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
                 # the subprocess and allow easy communication
                 POE::Kernel->stop();
                 
-                Class::MOP::load_class($class);
+                Class::MOP::load_class($_) for @$classes;
                 POEx::WorkerPool::Worker::Guts->new();
 
                 POE::Kernel->run();
@@ -154,9 +154,12 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
         $self->call($alias, 'publish', event_name => +PXWP_JOB_PROGRESS);
         $self->call($alias, 'publish', event_name => +PXWP_JOB_FAILED);
         $self->call($alias, 'publish', event_name => +PXWP_JOB_START);
+        $self->call($alias, 'publish', event_name => +PXWP_WORKER_ERROR);
 
         $self->alias('Worker:'.$self->uuid);
 
+        $self->poe->kernel->sig('DIE', 'die_signal_handler');
+
         $self->child_wheel();
     }
 
@@ -343,6 +346,18 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
                 job => $self->_in_process,
             );
         }
+        elsif($job_status->{type} eq +PXWP_WORKER_INTERNAL_ERROR)
+        {
+            $self->post
+            (
+                $self->pubsub_alias, +PXWP_WORKER_INTERNAL_ERROR,
+                worker_id => $self->ID,
+                job => $self->_in_process,
+                msg => $job_status->{msg},
+            );
+
+            $self->halt();
+        }
         else
         {
             JobError->throw({message => 'Unknown job status', job => $self->_in_process, job_status => $job_status});
@@ -356,6 +371,20 @@ role POEx::WorkerPool::Role::WorkerPool::Worker
         $self->child_wheel->kill();
         $self->clear_alias();
     }
+
+
+    method die_signal_handler(Str $sig, HashRef $error) is Event
+    {
+        $self->poe->kernel->sig_handled();
+
+        $self->poe->kernel->post
+        (
+            $self->pubsub_alias, +PXWP_WORKER_ERROR,
+            worker_id => $self->ID,
+            exception => $error->{error_str},
+            original => $error,
+        );
+    }
 }
 
 1;
@@ -371,16 +400,16 @@ POEx::WorkerPool::Role::WorkerPool::Worker - A role that provides common semanti
 
 =head1 VERSION
 
-version 0.092530
+version 0.092560
 
 =head1 ATTRIBUTES
 
-=head2 job_class is: ro, isa: ClassName, required: 1
+=head2 job_classes is: ro, isa: ArrayRef[ClassName], required: 1
 
 In order for the serializer on the other side of the process boundary to
-rebless jobs on the other side, it needs to make sure that class is loaded.
+rebless jobs on the other side, it needs to make sure those classes are loaded.
 
-This attribute is used to indicate which class needs to be loaded.
+This attribute is used to indicate which classes need to be loaded.
 
 
 
@@ -614,7 +643,7 @@ describes the potential events from the child and the actions taken
         PubSub event posted.
 
     PubSub Event:
-        +PXWP_JOB_COMPLETE
+        +PXWP_JOB_PROGRESS
 
     PubSub Signature:
         method handler
@@ -675,6 +704,19 @@ that the Session will stop
 
 
 
+=head2 die_signal_handler(Str $sig, HashRef) is Event
+
+This is the handler for any exceptions that are thrown. All exceptions will be
+relayed to the consumer via a PubSub published event: +PXWP_WORKER_ERROR
+
+Subscribers will need the following signature:
+
+    method handler(SessionID :$worker_id, IsaError :$exception, HashRef :$original) is Event
+
+Note that $original will be what was given to us from POE
+
+
+
 =head1 AUTHOR
 
   Nicholas Perez <nperez@cpan.org>
